<?php
/**
 * Clase MercadoRepresentanteBL
 *
 * @package    
 * @subpackage 
 * @author     MercadoRepresentanteBL
 * @version    SVN: $Id: MercadoRepresentanteBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class MercadoRepresentanteBL{
    
  /**
  * 
  *
  * @param $o_MercadoRepresentanteBean, objeto de tipo MercadoRepresentante 
  * @return Boolean
  */
  public function getMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
    
    $o_MercadoRepresentanteCT = new MercadoRepresentanteCT();
    return $o_MercadoRepresentanteCT->seleccionar($o_MercadoRepresentanteBean);
    
  }
  
  
  
  public function realizarMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
    
    
  }
  
  
   public function busquedaMercadoRepresentanteDetalle(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
    
    $tmp_ObjMercadoRepresentante = $this->getMercadoRepresentante($o_MercadoRepresentanteBean);
    
    if (is_array($tmp_ObjMercadoRepresentante)){
      
      foreach ($tmp_ObjMercadoRepresentante as $iKey => $tmp_MercadoRepresentanteBean){
        
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_MercadoRepresentanteBean->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
        $tmp_MercadoRepresentanteBean->setObjectColaborador($o_ColaboradorBean);
        
      }
      
    }else{
      
      if($tmp_ObjMercadoRepresentante){
      
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_ObjMercadoRepresentante->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
        $tmp_ObjMercadoRepresentante->setObjectColaborador($o_ColaboradorBean);
        
      }else{
        
        return array();
        
      }
      
    }
    
    return $tmp_ObjMercadoRepresentante;
   
     
  }
  
  
  
  /*public function busquedaMercadoRepresentanteDetalle(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
    
    $tmp_ObjMercadoRepresentante = $this->getMercadoRepresentante($o_MercadoRepresentanteBean);
    
    if (is_array($tmp_ObjMercadoRepresentante)){
      
      foreach ($tmp_ObjMercadoRepresentante as $iKey => $tmp_MercadoRepresentanteBean){
        
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_MercadoRepresentanteBean->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
        $tmp_MercadoRepresentanteBean->setObjectColaborador($o_ColaboradorBean);
        
      }
      
    }else{
      
      if($tmp_ObjMercadoRepresentante){
      
        $o_ColaboradorBean = new ColaboradorBean();
        $o_ColaboradorBean->setIdColaborador($tmp_ObjMercadoRepresentante->getIdColaborador());
        $o_ColaboradorBL = new ColaboradorBL();
        $o_ColaboradorBean = $o_ColaboradorBL->busquedaColaborador($o_ColaboradorBean);
        
       $tmp_ObjMercadoRepresentante->setObjectColaborador($o_ColaboradorBean);
        
      }else{
        
        return array();
        
      }
      
    }
    
    return $tmp_ObjMercadoRepresentante;
   
     
  }*/
  /**
	* Función que retorna un objeto MercadoRepresentante o una lista de Objetos de MercadoRepresentante,
	* dependiendo del parametro que se le envia si este contiene o no el Id de MercadoRepresentante
	*
	* @param $o_MercadoRepresentanteBean, es un objeto de tipo MercadoRepresentante
	* @return Object
	*/
   public function modificarEstadoMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
	  $o_MercadoRepresentanteCT = new MercadoRepresentanteCT();
    return $o_MercadoRepresentanteCT->modificar($o_MercadoRepresentanteBean);
	}
  
	public function modificarMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
	  $o_MercadoRepresentanteCT = new MercadoRepresentanteCT();
    return $o_MercadoRepresentanteCT->modificar($o_MercadoRepresentanteBean);
	}
  
    public function eliminarMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
    $o_MercadoRepresentanteCT = new MercadoRepresentanteCT();
    return $o_MercadoRepresentanteCT->eliminar($o_MercadoRepresentanteBean);
  }
  
   
 
  
  public function insertarMercadoRepresentante(MercadoRepresentanteBean $o_MercadoRepresentanteBean){
     $o_MercadoRepresentanteCT = new MercadoRepresentanteCT();
     return $o_MercadoRepresentanteCT->guardar($o_MercadoRepresentanteBean);
  }
  
  
}